@@ -4,7 +4,8 @@
 
 """
 
-__all__ = ['ExtractError', 'RefError', 'LastElement', 'OutOfBounds', 'OutOfRange', 'WrongType']
+__all__ = ['ExtractError', 'RefError', 'LastElement', 'OutOfBounds',
+           'OutOfRange', 'WrongType', 'UnstagedError']
 
 
 class ExtractError(Exception):
@@ -51,3 +52,10 @@ class LastElement(ExtractError):
 
     :ivar obj: the object that raised this event
     """
+
+
+class UnstagedError(ExtractError, ValueError):
+    """Raised when obj is not staged.
+
+    :ivar obj: the object that raised this event
+    """
