@@ -4,17 +4,15 @@
 
 """
 
-__all__ = ['load', 'register', 'Factory', 'Validator', 'ReferenceValidator',
+__all__ = ['load', 'register', 'Factory',
+           'Validator', 'ReferenceValidator', 'Draft04Validator',
            'CompilationError', 'ReferenceError', 'ValidationError']
 
-from .bases import error, Validator, ReferenceValidator, NotValidator
-from .bases import CompoundValidator, AllValidator, AnyValidator, OneValidator
-from .types import EnumValidator, StringValidator, NumberValidator
-from .types import IntegerValidator, IntegerValidator, NullValidator
-from .types import ArrayValidator, ObjectValidator, BooleanValidator
-from .exceptions import CompilationError, ReferenceError, ValidationError
-from .factorize import register, Context, Factory
+from .bases import Validator, ReferenceValidator
+from .exceptions import error, CompilationError, ReferenceError, ValidationError
+from .factorize import register, Factory, Context
 from . import draft04  # noqa
+from .draft04 import Draft04Validator  # noqa
 
 
 def load(schema, uri=None, spec=None, provider=None):
